#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_FREXP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_FREXP_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/frexp.hpp>

#endif
